match

package
v5.5.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetIdentifiersFromContent added in v5.5.1

func GetIdentifiersFromContent(filename, content string) []string

GetIdentifiersFromContent extracts function names, variable names, type names, and other identifiers from code content. It auto-detects the language based on the file extension. For Go files, it uses the go/ast parser for accurate extraction.

func GetImportWordsFromGoFile

func GetImportWordsFromGoFile(filename string) []string

func MatchFilter

func MatchFilter(file, filter string) bool

MatchFilter checks if a file matches a filter.

Parameters:

  • file: the file to be checked.
  • filter: the filter to be matched against the file.

Returns:

  • bool: true if the file matches the filter, false otherwise.
  • error: an error if there was a problem during the matching process.

Types

This section is empty.

Jump to