Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetIdentifiersFromContent ¶ added in v5.5.1
GetIdentifiersFromContent extracts function names, variable names, type names, and other identifiers from code content. It auto-detects the language based on the file extension. For Go files, it uses the go/ast parser for accurate extraction.
func MatchFilter ¶
MatchFilter checks if a file matches a filter.
Parameters:
- file: the file to be checked.
- filter: the filter to be matched against the file.
Returns:
- bool: true if the file matches the filter, false otherwise.
- error: an error if there was a problem during the matching process.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.